@@ -11,7 +11,7 @@
 
 #include "explain.h"
 #include "filters.h"
-#include "plocate.h"
+#include "locate.h"
 #include "dpkg.h"
 #include "shellexp.h"
 
@@ -160,7 +160,7 @@ int main(int argc, char *argv[])
 	}
 
 	vector<string> fs;
-	read_plocate(fs, "/usr/share/cruft/ignore");
+	read_locate(fs, "/usr/share/cruft/ignore");
 	elapsed("plocate");
 
 	if (csv) cout << "path;package;type;cruft;size" << endl;
